CheckoutResponse class

Constructors

CheckoutResponse({required String message, required String? reference, required bool status, required CheckoutMethod method, required String? name, required bool verify, required double? confidenceLevel, required String? bvn, required String? nin, String? base64Image})
CheckoutResponse.defaults()

Properties

base64Image ↔ String?
The base64 encoded image of the image capture
getter/setter pair
bvn ↔ String?
The confidence_level of the transaction. A successful response returns 0 to 100 otherwise
getter/setter pair
confidenceLevel ↔ double?
The confidence_level of the transaction. A successful response returns 0 to 100 otherwise
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
A user readable message. If the transaction was not successful, this returns the cause of the error.
getter/setter pair
method ↔ CheckoutMethod
The means of payment. It may return CheckoutMethod.bank or CheckoutMethod.card
getter/setter pair
name ↔ String?
getter/setter pair
nin ↔ String?
getter/setter pair
reference ↔ String?
Transaction reference. Might be null for failed transaction transactions
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ bool
The status of the transaction. A successful response returns true and false otherwise
getter/setter pair
verify ↔ bool
If the transaction should be verified. See https://developers.Duplo.co/v2.0/reference#verify-transaction. This is usually false for transactions that didn't reach Duplo before terminating
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

aggregate({required String message, required String? reference, required bool status, required CheckoutMethod method, required String? name, required double? confidenceLevel, required String? bvn, required String? nin, String? base64Image}) → CheckoutResponse