SprintCheck class
The main class for interacting with the SprintCheck SDK.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkout(
BuildContext context, CheckoutMethod checkoutmethod, String identifier, {String? bvn, String? nin}) → Future< CheckoutResponse> - Starts the checkout process.
-
getPlatformVersion(
) → Future< String?> - Returns the current platform version.
-
initialize(
{required String apiKey, required String encryptionKey}) → void - Initializes the SprintCheck SDK.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited